==> kittywalk-0.2.1.tar.gz: kittywalk-0.2.1/ui/userinterface.py <==
"""UserInterface"""
from thread import start_new_thread

from qt import *

from ui.mainwindow import MainWindow
from ui.renderer import Renderer


class UserInterface(QApplication):
    """User interface controller"""
    def __init__(self, app):
        QApplication.__init__(self, [])
        self._app = app
        self._main_window = MainWindow()
        self._renderer = Renderer()
        self.setMainWidget(self._main_window)
        self.connect(self._main_window,
                     PYSIGNAL("requestOpenTopicList"),
                     self._open_topic_list)
        self.connect(self._main_window,
                     PYSIGNAL("requestSyncTopicList"),
                     self._sync_topic_list)
        self.connect(self._main_window,
                     PYSIGNAL("requestOpenMessages"),
                     self._open_messages)
        self.connect(self._main_window,
                     PYSIGNAL("requestSyncMessages"),
                     self._sync_messages)
        self.connect(self._main_window,
                     PYSIGNAL("requestChangeFont"),
                     self._change_font)

    def start(self):
        """Starts user interface

        This method 
        """
        self._main_window.show()
        self._main_window.display_board_tree(self._app.bbs())
        self.exec_loop()

    def echo(self, text):
        self._main_window.echo(text)

    def _open_topic_list(self, board, newtab):
        def proc(board, newtab):
            topics = self._app.topic_list(board)
            self._main_window.display_topic_list(board, topics, newtab)
        start_new_thread(proc, (board, newtab))

    def _sync_topic_list(self, board):
        def proc(board):
            topics = self._app.latest_topic_list(board)
            self._main_window.display_topic_list(board, topics, False)
        start_new_thread(proc, (board,))

    def _open_messages(self, topic, newtab=None):
        def proc(topic, newtab):
            messages = self._app.messages(topic, self._renderer)
            self._main_window.display_messages(topic, messages, newtab)
        start_new_thread(proc, (topic, newtab))


    def _sync_messages(self, topic):
        def proc(topic):
            messages = self._app.latest_messages(topic, self._renderer)
            self._main_window.display_messages(topic, messages, False)
        start_new_thread(proc, (topic,))

    def _change_font(self, font):
        font, ok = QFontDialog.getFont(font, None)
        if ok:
            self._main_window.set_message_font(font)

==> kittywalk-0.2.2.tar.gz: kittywalk-0.2.2/ui/userinterface.py <==
"""UserInterface"""
from thread import start_new_thread

from qt import *

from ui.mainwindow import MainWindow
from ui.renderer import Renderer


class UserInterface(QApplication):
    """User interface controller"""
    def __init__(self, app):
        QApplication.__init__(self, [])
        self._app = app
        self._main_window = MainWindow()
        self._renderer = Renderer()
        self.setMainWidget(self._main_window)
        self.connect(self._main_window,
                     PYSIGNAL("requestOpenTopicList"),
                     self._open_topic_list)
        self.connect(self._main_window,
                     PYSIGNAL("requestReloadTopicList"),
                     self._reload_topic_list)

        self.connect(self._main_window,
                     PYSIGNAL("requestOpenMessages"),
                     self._open_messages)
        self.connect(self._main_window,
                     PYSIGNAL("requestReloadMessages"),
                     self._reload_messages)
        self.connect(self._main_window,
                     PYSIGNAL("requestChangeFont"),
                     self._change_font)

    def start(self):
        """Starts user interface

        This method 
        """
        self._main_window.show()
        self._main_window.display_board_tree(self._app.bbs())
        self.exec_loop()

    def echo(self, text):
        self._main_window.echo(text)

    def _open_topic_list(self, board, newtab):
        def proc(board, newtab):
            topics = self._app.topic_list(board)
            self._main_window.display_topic_list(board, topics, newtab)
        start_new_thread(proc, (board, newtab))

    def _reload_topic_list(self, board):

        def proc(board):
            topics = self._app.latest_topic_list(board)
            self._main_window.display_topic_list(board, topics, False)
        start_new_thread(proc, (board,))

    def _open_messages(self, topic, newtab=None):
        def proc(topic, newtab):
            messages = self._app.messages(topic, self._renderer)
            self._main_window.display_messages(topic, messages, newtab)
        start_new_thread(proc, (topic, newtab))

    def _reload_messages(self, topic):

        def proc(topic):
            messages = self._app.latest_messages(topic, self._renderer)
            self._main_window.display_messages(topic, messages, False)
        start_new_thread(proc, (topic,))

    def _change_font(self, font):
        font, ok = QFontDialog.getFont(font, None)
        if ok:
            self._main_window.set_message_font(font)
